## Copyright (C) 2022 John Donoghue <john.donoghue@ieee.org>
##
## This program is free software; you can redistribute it and/or modify it under
## the terms of the GNU General Public License as published by the Free Software
## Foundation; either version 3 of the License, or (at your option) any later
## version.
##
## This program is distributed in the hope that it will be useful, but WITHOUT
## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
## details.
##
## You should have received a copy of the GNU General Public License along with
## this program; if not, see <http://www.gnu.org/licenses/>.

## -*- texinfo -*-
## @deftypefn {} {[@var{numkeys}, @var{freekeys}] = } getHdrSpace(@var{file})
## Get the number of keyword records used and available.
##
## This is the equivalent of the cfitsio fits_get_hdrspace function.
##
## @subsubheading Inputs
## @var{file} - opened fits file.
##
## @subsubheading Outputs
## @var{numkeys} - number of existing keys.
##
## @var{freekeys} - number of free key space.
## @end deftypefn
function [numkeys, freekeys] = getHdrSpace (file)
  [numkeys, freekeys] = __cfitsio_getHdrSpace__(file);
endfunction

%!test
%! testfile = file_in_loadpath("demos/tst0012.fits");
%! fd = matlab.io.fits.openFile(testfile);
%! assert(!isempty(fd));
%! [numkeys, freekeys] = matlab.io.fits.getHdrSpace(fd);
%! assert(numkeys, 23);
%! assert(freekeys, 12);
%! matlab.io.fits.closeFile(fd);

%!error matlab.io.fits.getHdrSpace(1);
%!error matlab.io.fits.getHdrSpace([]);

